% beispiele.m
% Kapitel 3: Eingabe und Ausgabe in MATLAB
%            Beispiele zum Skript

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
format compact;     % Ermglicht kompakte Ausgabe ohne Leerzeilen
echo on;            % Ermglicht Ausgabe aller Zeilen im Command Window

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3.1 Steuerung der Bildschirmausgabe

echo mittelwerte on
[A, G] = mittelwerte (1:2:7)
echo mittelwerte off

for i=1:2:6
    disp (i)
    pause (i)
end
disp ('Ende')
pause

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3.2 Benutzerdialoge

text = ['Das ist', ' ', 'ein Text!']
whos text

preis = input (['Wieviel kostet heuer \n', ...
                'die Wies''n-Ma ?      '])
waehrung = input ('Whrung ?             ', 's');

disp (['Aber ', num2str(preis, '%0.2f'), ' ', waehrung, ...
       ' pro Ma wird ein teurer Rausch!'])
disp (' ')                                                   % Leerzeile
ausgabe = sprintf ('Zwei Ma kosten dann %2.2f %s.', ...
                    preis*2, waehrung)
disp (ausgabe)
mehr = sprintf ('%4d Ma kosten dann %2.2f.\n', ...
                [3:5; (3:5)*preis])
disp (mehr)

pause
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3.3 Import und Export von Daten
%     Die folgenden Zeilen bentigen Schreibrecht im aktuellen Verzeichnis
%     andernfalls bitte auskommentieren

clear

test_vektor = [0:0.1:10]';                       % Spaltenvektor
test_matrix = [test_vektor cos(test_vektor)];    % Matrix

save test                          % Speichern in Datei test.mat
clear                              % Workspace lschen
load test                          % Laden aus Datei test.mat
who                                % Anzeige des Workspace

save test.txt -ascii test_matrix   % Speichern in Datei test.txt
clear                              % Workspace lschen
load test.txt                      % Laden aus Datei test.txt
who                                % Anzeige des Workspace


preis = 6.80;
bier_id = fopen ('bier.txt', 'w');
fprintf (bier_id, '%4d Ma kosten dann %2.2f.\r\n', ...
                    [3:5; (3:5)*preis]);
fclose (bier_id);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3.4 Betriebssystemaufruf und Dateiverwaltung

mkdir ('testverzeichnis')
verzeichnis = dir ('testverzeich*');
eval (['!rmdir ', verzeichnis.name])

pause
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 3.5 Graphische Darstellung

figure
gcf

get (gcf)
get (gcf, 'Position')
set (gcf, 'Position', [10 50 400 200])

pause
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Zweidimensionale Graphiken

figure                                            % Erzeugt neue Figure
subplot (121)                                     % Linker Subplot
    plot ([-5:0.1:5], cos ((-5:0.1:5)*pi), 'k:')  % schwarz, gepunktet
    hold on                                       % alten Plot beibehalten
    fplot ('2*sinc(x)', [-5 5], 'k--')            % schwarz, gestrichelt
subplot (122)                                     % Rechter Subplot
    t = (0:20)*0.9*pi;
    plot (cos (t), sin (t))                       % Standard: blaue Linie

figure
subplot (221)
    ezplot ('x^2 - y^2 -2')
subplot (222)
    ezplot ('sin(3*t) * cos(t) / (t+pi)', 'sin(3*t) * sin(t) / (t+pi)', [0,4*pi])
        
pause

% Berechnung des Frequenzgangs eines Tiefpasses und Hochpasses mit
% der Zeitkonstante T im Laplace-Bereich: 1/(1+sT) mit s = j*omega

T                 = 0.05;                        % Zeitkonstante [s]
omega             = logspace (0, 3, 100);        % Frequenzvektor [rad/s]
frequenzgang_TP   = (T*j*omega + 1).^(-1);       % Frequenzgang Tiefpass
frequenzgang_HP   = 1 - frequenzgang_TP;         % Frequenzgang Hochpass

figure (3)                                       % Erzeugt Figure 3
clf                                              % Lscht ggf. alte Plots

subplot (121)                                    % Linker Subplot: Amplitude
    loglog (omega, abs (frequenzgang_TP), '-')   % Amplitudengang Tiefpass
    hold on
    loglog (omega, abs (frequenzgang_HP), '--')  % Amplitudengang Hochpass
    loglog ([1 1]/T, [0.01 10], ':')             % Linie Zeitkonstante
    text (1.1/T, 0.02, 'Zeitkonstante')          % Text Zeitkonstante
    title ('bertragungsfunktionen')             % Titel linker Subplot
    xlabel ('\omega [rad s^-^1]')                % Achsenbeschriftung X
    ylabel ('Amplitude [dB]')                    % Achsenbeschriftung Y
    legend ('Tiefpass', 'Hochpass', 2)           % Legende links oben
    axis ([1 1e3 0.01 10])                       % Sichtbarer Bereich
    skala = -40:20:40;                           % Gewnschte Achsteilung
    set (gca, 'ytick', 10.^(skala/20))           % Setzt Achsteilung (dB)
    set (gca, 'yticklabel', skala)               % Setzt Beschriftung

subplot (122)                                    % Rechter Subplot: Phase
    semilogx (omega, angle (frequenzgang_TP) *180/pi, '-')  % Phasengang TP
    hold on
    semilogx (omega, angle (frequenzgang_HP) *180/pi, '--') % Phasengang HP
    grid on                                      % Aktiviert Gitterlinien
    xlabel ('\omega [rad s^-^1]')                % Achsenbeschriftung X
    ylabel ('Phase [Grad]')                      % Achsenbeschriftung Y
    axis ([1 1e3 -90 90])                        % Sichtbarer Bereich
    skala = -90:30:90;                           % Gewnschte Achsteilung
    set (gca, 'ytick', skala)                    % Setzt Achsteilung (Grad)
    set (gca, 'yticklabel', skala)               % Setzt Beschriftung

figure
tiefpass = tf ([1], [0.05 1]);
hochpass = 1 - tiefpass;
bode (tiefpass, 'b-', hochpass, 'r--')

pause
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dreidimensionale Graphiken (3D-Graphik)

figure (5)
phi = (0:100) / 100 * 2*pi;
plot3 (sin (2*phi), cos (3*phi), phi, 'b*')

pause

% Beispiel

x = 0:0.05:2;
y = -1:0.2:1;

[X, Y] = meshgrid (x, y);       % Erzeugt Matrizen ber Bereich von x, y
Z      = (Y+1) .* cos (2*X.^2) + (Y-1) .* sin (2*X.^2) / 5;

figure
subplot (221)
    surf (X, Y, Z)
    view (-40, 30)
    title ('surf (X, Y, Z); view (-40, 30)')
subplot (222)
    mesh (X, Y, Z)
    view (-20, 30)
    title ('mesh (X, Y, Z); view (-20, 30); grid off; box on')
    grid off
    box on
subplot (223)
    waterfall (X, Y, Z)
    view (-20, 10)
    title ('waterfall (X, Y, Z); view (-20, 10)')
subplot (224)
    contour (X, Y, Z)
    title ('contour (X, Y, Z)')

pause
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Importieren, Exportieren und Drucken von Graphiken

% Bilder Einbinden

figure
foto_variable = imread ('foto.jpg', 'jpeg');
image (foto_variable)

% Drucken

% print -f1;                % Drucken von Figure 1 auf Standarddrucker
% print -f1 -dmeta 'bild';  % Speichern als Windows-Metafile (bild.emf)
% print -f1 -depsc 'bild';  % Speichern als Farb-Postscript  (bild.eps)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
echo off
format
